'--------------------------------------------------------------
' Project  : RemoteOSD
' Purpose  : Add on to F1MIJ / F1CJN Simple OSD Generator
'          : Enables Caption Selection from Sony IR Remote
' Author   : Mike G7GTN - for CQ-DATV eBook Magazine
' Date     : 24/05/2013
'
' Hardware : 12F683, TSOP2348, TSOP4838, or PC3388
'            Heartbeat Led is optional.
'-------------------------------------------------------------

' Set up device fuses
Device = 12F683
Config INTRC_OSC_NOCLKOUT, WDT_OFF, PWRTE_ON, MCLRE_OFF 
Xtal 4                                      		  ;4MHz Internal Clock

All_Digital = TRUE	                        		  ;Make all I/O Digital
ANSEL = 0
CMCON1 = 7
Declare Optimiser_Level = 1                			  ;Set Compiler optimiser level
Declare Sonyin_Pin = GPIO.3                 		  ;Port Pin for 38KHz IR Sensor

' Alias OSD RB.5 - RB.7 Pin names
Symbol OSDRB5 = GPIO.2                     			  ; Pic Pin 11 OSD Generator
Symbol OSDRB6 = GPIO.1                    			  ; Pic Pin 12 OSD Generator
Symbol OSDRB7 = GPIO.0                      		  ; Pic Pin 13 OSD Generator
Symbol HB = GPIO.5                          		  ; Heartbeat LED * optional

' Make Pins all outputs
Output OSDRB5
Output OSDRB6
Output OSDRB7

' You could create Alias names for buttons and call these instead of numbers eg.
Symbol CDown = 26                            			;Remote Colour Down
Symbol CUp   = 27                         			    ;Remote Colour Up 
Symbol Red = 76                             			;Teletext Red
Symbol green = 77                                       ;Teletext Green
Symbol yellow = 78                                      ;Teletext Yellow
Symbol blue = 79                            			;Teletext Blue

' Dimension required variables
Dim SonyIn_Word As Word                     			;Create a Word variable to receive the SIRC data
Dim SonyCommand As SonyIn_Word.LowByte      			;Alias the Command byte to SonyIn_Word low byte
Dim SonySystem As SonyIn_Word.HighByte      			;Alias the System byte to SonyIn_Word high byte
 
' Decode SIRCS IR and branch on command.
' Change Case numbers to match required Buttons on Sony Remote.
' Here are a few decoded for you: -
'
' Code      Button
' --------------------------------
' 116     + key
' 117     - key
' 030     Brightness up
' 031     Brightness down
' 026     Color up
' 027     Color down
'
' More detailed information on the Sony Sircs Protocol can be found here
' http://www.edcheung.com/automa/sircs.htm

' Start
Main:      
    While 1 = 1                                                   ;Create a never ending loop
    GoSub Heartbeat                                               ;Flash LED as Heartbeat Signal
    Repeat							                              ;Repeat Block                                       
      SonyIn_Word = SonyIn                                        ;Receive a signal from the infrared sensor
      Until SonyCommand <> 255                                    ;Keep looking until a valid header has been found  
      Select SonyCommand                                          ;Sort out IR codes from here
             Case 1                                               ;Remote Button  1 =  0 Decimal
               GoSub Caption_1
             Case 2                                               ;Remote Button  2 =  1 Decimal
               GoSub Caption_2
             Case 3                                               ;Remote Button  3 =  2 Decimal
               GoSub Caption_3
             Case 4                                               ;Remote Button  4 =  3 Decimal
               GoSub Caption_4
             Case 5                                               ;Remote Button  5 =  4 Decimal 
               GoSub Caption_5
             Case 6                                               ;Remote Button  6 =  5 Decimal
               GoSub Caption_6
             Case 7                                               ;Remote Button  7 =  6 Decimal 
               GoSub Captions_Off                                 ;Turn Caption/Callsign off  
      EndSelect
    Wend

'---------------------------------------------------
' Logic levels to place on pins to switch captions
' PIC RB.5   RB.6     RB.7      Caption Selected
' --------------------------------------------------
'      1       0       0         Number 1
'      0       1       0         Number 2
'      1       1       0         Number 3
'      0       0       1         Number 4
'      1       0       1         Number 5
'      0       1       1         Number 6
'      1       1       1         Off 

Caption_1:
 High OSDRB5
 Low OSDRB6
 Low OSDRB7
Return

Caption_2:
 Low OSDRB5
 High OSDRB6
 Low OSDRB7
Return

Caption_3:
 High OSDRB5
 High OSDRB6
 Low OSDRB7
Return

Caption_4:
 Low OSDRB5
 Low OSDRB6
 High OSDRB7
Return

Caption_5:
 High OSDRB5
 Low OSDRB6
 High OSDRB7
Return

Caption_6:
 Low OSDRB5
 High OSDRB6
 High OSDRB7
Return

Captions_Off:
 High OSDRB5
 High OSDRB6
 High OSDRB7
Return

' User Optional. Shows that PIC is programmed OK
' Flash on 700ms, off 700ms
Heartbeat:
 High HB                                                          ;I/O Led is attached to
 DelayMS 700
 Low HB
 DelayMS 700
Return

  End
